import { LyticsAccount, DataStream, DataStreamField, TableSchema, TableSchemaFieldInfo, Query, CollectResultInfo, SegmentGrouping, Segment, Campaign, CampaignVariation, ContentClassification, CampaignVariationDetailOverride, Topic, TopicUrlCollection, Subscription, WebhookConfig, CreateAccessTokenConfig, LyticsAccessToken, TokenScope, LyticsAccountSetting, DocumentTopics, DataUploadResponse, DataUploadConfig, FragmentCollection, SegmentMLModel, CreateSegmentMLModelConfig, SegmentCollection, QueryValidationResult } from './types';
export declare class LyticsClientOptions {
    base_url: string;
    readonly apikey: string;
    constructor(apikey: string);
}
export declare class LyticsClient {
    private base_url;
    private apikey;
    private headers;
    constructor(apikey: string);
    static create(options: LyticsClientOptions): LyticsClient;
    private doRequest;
    private doGet;
    private doPost;
    private doPut;
    private doDelete;
    getAccounts(): Promise<LyticsAccount[]>;
    getAccount(aid: number): Promise<LyticsAccount | undefined>;
    getStreams(): Promise<DataStream[]>;
    getStream(name: string): Promise<DataStream | undefined>;
    getStreamField(streamName: string, fieldName: string): Promise<DataStreamField | undefined>;
    getTableSchema(tableName: string): Promise<TableSchema | undefined>;
    getTableSchemaFieldInfo(tableName: string, fieldName: string): Promise<TableSchemaFieldInfo | undefined>;
    getEntity(tableName: string, fieldName: string, fieldValue: any, wait?: boolean): Promise<any>;
    getQueries(): Promise<Query[]>;
    getQuery(alias: string): Promise<Query | undefined>;
    upsertQuery(lql: string): Promise<Query[]>;
    deleteQuery(alias: string): Promise<boolean>;
    validateQuery(lql: string): Promise<QueryValidationResult>;
    getQueriesGroupedByTable(): Promise<Map<string, Query[]>>;
    toLql(csvText: string): Promise<string | undefined>;
    testQuery(lql: string, record: any): Promise<any>;
    collect(stream: string, data: any): Promise<CollectResultInfo | undefined>;
    getSegments(): Promise<Segment[]>;
    getSegment(idOrSlug: string): Promise<Segment | undefined>;
    getSegmentGrouping(ids?: string[]): Promise<SegmentGrouping>;
    getSegmentCollections(): Promise<SegmentCollection[]>;
    getSegmentCollection(idOrSlug: string): Promise<SegmentCollection | undefined>;
    private isNullOrWhitespace;
    getCampaigns(): Promise<Campaign[]>;
    getCampaign(id: string): Promise<Campaign | undefined>;
    getCampaignVariationsAll(): Promise<Map<string, CampaignVariation[]>>;
    getCampaignVariations(campaignId: string): Promise<CampaignVariation[]>;
    getCampaignVariation(variationId: string): Promise<CampaignVariation | undefined>;
    updateCampaignVariation(variationId: string, variation: CampaignVariation): Promise<CampaignVariation | undefined>;
    getCampaignVariationDetailOverride(variationId: string): Promise<CampaignVariationDetailOverride | undefined>;
    updateCampaignVariationDetailOverride(variationId: string, override: CampaignVariationDetailOverride): Promise<CampaignVariation | undefined>;
    classifyUsingText(text: string, draft?: boolean): Promise<ContentClassification | undefined>;
    classifyUsingUrl(url: string, draft?: boolean): Promise<ContentClassification | undefined>;
    testFunction(functionName: string, args?: string[]): Promise<any | undefined>;
    getWhitelistFields(aid: number): Promise<string[]>;
    /**
     *
     * @param aid
     * @param fieldName
     * @param add
     * @returns true if a change was made; false if no change was made. For example, if the field "email" is already whitelisted and try to add "email" to the whitelist, this function returns false.
     */
    setWhitelistFieldStatus(aid: number, fieldName: string, add: boolean): Promise<boolean>;
    getTopics(limit?: number): Promise<Topic[]>;
    getTopic(label: string): Promise<Topic | undefined>;
    getTopicUrls(label: string, limit?: number): Promise<TopicUrlCollection>;
    getSubscriptions(): Promise<Subscription[]>;
    getSubscription(id: string): Promise<Subscription | undefined>;
    createWebhook(config: WebhookConfig): Promise<Subscription | undefined>;
    updateWebhook(id: string, config: WebhookConfig): Promise<Subscription | undefined>;
    deleteSubscription(id: string): Promise<boolean>;
    getTokenScopes(): Promise<TokenScope[]>;
    createAccessToken(config: CreateAccessTokenConfig): Promise<LyticsAccessToken | undefined>;
    getAccessTokens(aid: number): Promise<LyticsAccessToken[]>;
    getAccessToken(authid: string, aid: number): Promise<LyticsAccessToken | undefined>;
    deleteAccessToken(authid: string, aid: number): Promise<boolean>;
    getAccountSettings(): Promise<LyticsAccountSetting[]>;
    getAccountSettingsGroupedByCategory(): Promise<Map<string, LyticsAccountSetting[]>>;
    getAccountSetting(slug: string): Promise<LyticsAccountSetting | undefined>;
    updateAccountSetting(slug: string, value: any): Promise<LyticsAccountSetting | undefined>;
    deleteAccountSetting(slug: string): Promise<boolean>;
    getDocumentTopics(docUrl: string): Promise<DocumentTopics | undefined>;
    uploadData(config: DataUploadConfig, data: any): Promise<DataUploadResponse>;
    getFragments(table: string, key: string, value: any): Promise<FragmentCollection | undefined>;
    getSegmentMLModels(): Promise<SegmentMLModel[]>;
    getSegmentMLModel(id: string): Promise<SegmentMLModel | undefined>;
    createSegmentMLModel(config: CreateSegmentMLModelConfig): Promise<SegmentMLModel | undefined>;
    deleteSegmentMLModel(name: string): Promise<boolean>;
}
