#!/usr/bin/env node
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston_1 = require("winston");
const util_1 = require("util");
const LyticsClient_1 = require("./LyticsClient");
const program = require("commander");
const jsome = require('jsome');
const logger = winston_1.createLogger({
    format: winston_1.format.combine(winston_1.format.colorize({ all: true }), winston_1.format.timestamp({
        format: 'YYYY-MM-DD hh:mm:ss.SSS'
    }), winston_1.format.printf(info => {
        return `${info.timestamp}\t${info.level}\t${info.message}`;
    })),
    transports: [new winston_1.transports.Console()]
});
program
    .description('Invokes the function, using the specified parameters.')
    .name('function')
    .usage('[options] <name> [param1 param2]')
    .option('-k, --key <key>', 'Lytics API key (if not specified, environment variable LIOKEY is used)')
    .parse(process.argv);
main();
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        //
        //validate and initialize
        if (program.args.length == 0) {
            logger.error('Function name must be specified');
            logger.error('Fatal error, aborting');
            return;
        }
        const name = program.args[0];
        const params = program.args.length > 1 ? program.args.slice(1) : [];
        var apikey = program.key;
        if (util_1.isNullOrUndefined(apikey)) {
            apikey = process.env.LIOKEY;
            if (util_1.isNullOrUndefined(apikey)) {
                logger.error('API key must be specified as an option or in the environment variable LIOKEY');
                logger.error('Fatal error, aborting');
                return;
            }
            logger.info(`API key from environment variable LIOKEY: ${apikey}`);
        }
        else {
            logger.info(`API key from options: ${apikey}`);
        }
        //
        //
        const client = new LyticsClient_1.LyticsClient(apikey);
        logger.info(`Calling ${name}(${params.join(', ')})`);
        try {
            var result = yield client.testFunction(name, params);
            logger.info(`Result: ${result}`);
        }
        catch (err) {
            logger.error(err.message);
        }
    });
}
//# sourceMappingURL=lytics-js-function.js.map