"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const FileReaders_1 = require("../FileReaders");
const fs = require("fs");
const tmp = require("tmp");
describe('CsvFileReader', function () {
    it('should throw an error if the csv file is not well-formed', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const file = tmp.fileSync();
            fs.appendFileSync(file.name, 'one,two,three,\n1,2,3\n');
            const reader = new FileReaders_1.CsvFileReader();
            try {
                yield reader.convert(file.name);
                chai_1.assert.isTrue(false, 'An error should have been thrown.');
            }
            catch (err) {
                chai_1.assert.isTrue(true, 'Error was thrown.');
            }
            finally {
                file.removeCallback();
            }
        });
    });
    it('should return 0 rows if the csv file has only a header row', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const file = tmp.fileSync();
            fs.appendFileSync(file.name, 'one,two,three');
            try {
                const reader = new FileReaders_1.CsvFileReader();
                const rows = yield reader.convert(file.name);
                chai_1.assert.isDefined(rows);
                chai_1.assert.isArray(rows);
                chai_1.assert.equal(rows.length, 0);
            }
            catch (err) {
                chai_1.assert.isTrue(false, 'No error should be thrown.');
            }
            finally {
                file.removeCallback();
            }
        });
    });
    it('should return 2 rows when no maxrows set', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const file = tmp.fileSync();
            fs.appendFileSync(file.name, 'one,two,three\n1,2,3\n4,5,6');
            try {
                const reader = new FileReaders_1.CsvFileReader();
                const rows = yield reader.convert(file.name);
                chai_1.assert.isDefined(rows);
                chai_1.assert.isArray(rows);
                chai_1.assert.equal(rows.length, 2);
            }
            catch (err) {
                chai_1.assert.isTrue(false, 'No error should be thrown.');
            }
            finally {
                file.removeCallback();
            }
        });
    });
    it('should return 2 rows when maxrows is 0', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const file = tmp.fileSync();
            fs.appendFileSync(file.name, 'one,two,three\n1,2,3\n4,5,6');
            try {
                const reader = new FileReaders_1.CsvFileReader();
                const rows = yield reader.convert(file.name);
                chai_1.assert.isDefined(rows);
                chai_1.assert.isArray(rows);
                chai_1.assert.equal(rows.length, 2);
            }
            catch (err) {
                chai_1.assert.isTrue(false, 'No error should be thrown.');
            }
            finally {
                file.removeCallback();
            }
        });
    });
    it('should return 1 row when maxrows is 1', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const file = tmp.fileSync();
            fs.appendFileSync(file.name, 'one,two,three\n1,2,3\n4,5,6');
            try {
                const reader = new FileReaders_1.CsvFileReader();
                const rows = yield reader.convert(file.name, 1);
                chai_1.assert.isDefined(rows);
                chai_1.assert.isArray(rows);
                chai_1.assert.equal(rows.length, 1);
            }
            catch (err) {
                chai_1.assert.isTrue(false, 'No error should be thrown.');
            }
            finally {
                file.removeCallback();
            }
        });
    });
});
//# sourceMappingURL=FileReaders.spec.js.map